#
# spec file for package xawtv
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %arm aarch64
%define _lto_cflags %{nil}
%endif

Name:           xawtv
Version:        3.107
Release:        3.3
Summary:        Video4Linux TV application (Athena)
License:        GPL-2.0-or-later
Group:          Hardware/TV
URL:            http://www.kraxel.org/blog/linux/xawtv/
Source0:        http://linuxtv.org/downloads/xawtv/%{name}-%{version}.tar.bz2
Source1:        xawtv.desktop
Source2:        motv.desktop
# PATCH-FIX-OPENSUSE v4l-conf_non-position-independent-executable_fix.patch asterios.dramis@gmail.com -- Fix non-position-independent-executable rpmlint warning for v4l-conf
Patch0:         v4l-conf_non-position-independent-executable_fix.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Replace-sys_siglist-with-strsignal.patch
BuildRequires:  aalib-devel
BuildRequires:  alsa-devel
BuildRequires:  gcc-c++
BuildRequires:  libdv-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libquicktime-devel
BuildRequires:  libv4l-devel
BuildRequires:  lirc-devel
BuildRequires:  ncurses-devel
BuildRequires:  openmotif-devel
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11
BuildRequires:  zvbi-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xp)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86dga)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       tv-common
Requires:       tv-fonts
Requires:       v4l-conf
Recommends:     pia
Suggests:       lirc
Conflicts:      xaw3dd
BuildRequires:  update-desktop-files

%description
xawtv is an X11 application for watching TV with your Linux box. It supports
video4linux devices (for example bttv cards, various USB webcams, ...). It uses
the Athena widgets.

%package -n motv
Summary:        Video4Linux TV application (Motif)
Group:          Hardware/TV
Requires:       tv-common
Requires:       tv-fonts
Requires:       v4l-conf
Recommends:     pia
Suggests:       lirc
Provides:       xawtv:%{_bindir}/motv

%description -n motv
motv is a X11 application for watching TV with your Linux box. It supports
video4linux devices (for example bttv cards, various USB webcams, ...).	It's
based on xawtv's code, but uses Motif to provide a better GUI.

Also includes the teletext/videotext viewer mtt.

%package -n tv-common
Summary:        Frequency tables and some Tools for motv and xawtv
Group:          Hardware/TV
Provides:       xawtv:%{_prefix}/X11R6/lib/X11/fonts/misc/led-iso8859-1.bdf

%description -n tv-common
This package includes frequency tables for various countries and some utilities
for xawtv and motv (xawtv-remote, for example).

%package -n v4l-conf
Summary:        Video4linux Configuration Tool
Group:          Hardware/TV
Requires(post): permissions
Provides:       xawtv:%{_bindir}/v4l-conf

%description -n v4l-conf
This is a small utility used to configure video4linux device drivers
(bttv, for example). xawtv, motv, and fbtv need it.

%package -n v4l-tools
Summary:        Video4linux terminal / command line utilities
Group:          Hardware/TV
Requires:       tv-common
Requires:       v4l-conf
Provides:       xawtv:%{_bindir}/v4lctl

%description -n v4l-tools
This package includes a bunch of command line utilities: v4lctl to
control video4linux devices; streamer to record movies; fbtv to watch
TV on the framebuffer console; ttv to watch tv on any ttv (powered by
aalib), webcam for capturing and uploading images, a curses radio
application, ...

%package -n alevtd
Summary:        HTTP server for Teletext pages
Group:          Productivity/Networking/Web/Servers

%description -n alevtd
alevtd reads the teletext pages from /dev/vbi and allows to fetch them
via http, i.e. you can read the teletext pages with a web browser.

%package -n pia
Summary:        Simple Movie Player
Group:          Productivity/Multimedia/Video/Players
Requires:       tv-common

%description -n pia
pia is a simple movie player which can playback AVI and QuickTime
movies recorded by xawtv, motv, and streamer. Other movies might work
as well.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure
make verbose=yes %{?_smp_mflags}

%install
%make_install SUID_ROOT=""

mkdir -p %{buildroot}%{_datadir}/pixmaps
install -pm 0644 contrib/xawtv48x48.xpm  %{buildroot}%{_datadir}/pixmaps/xawtv.xpm
install -pm 0644 contrib/xawtv48x48.xpm  %{buildroot}%{_datadir}/pixmaps/motv.xpm

%suse_update_desktop_file -i xawtv
%suse_update_desktop_file -i motv

%verifyscript -n v4l-conf
%verify_permissions -e %{_bindir}/v4l-conf

%post -n v4l-conf
%if 0%{?set_permissions:1} > 0
  %{set_permissions %{_bindir}/v4l-conf}
%else
  %run_permissions
%endif

%files
%license COPYING
%doc Changes README README.* TODO
%doc contrib/frequencies* contrib/vdr.config
%{_bindir}/xawtv
%{_bindir}/rootv
%{_mandir}/man1/xawtv.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/xawtv.1%{ext_man}
%doc %lang(fr) %{_mandir}/fr/man1/xawtv.1%{ext_man}
%{_mandir}/man1/rootv.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/rootv.1%{ext_man}
%{_datadir}/X11/app-defaults/Xawtv
%{_datadir}/applications/xawtv.desktop
%{_datadir}/pixmaps/xawtv.xpm

%files -n motv
%license COPYING
%doc Changes README README.* TODO
%doc contrib/frequencies* contrib/vdr.config
%{_bindir}/motv
%{_mandir}/man1/motv.1%{?ext_man}
%{_datadir}/X11/app-defaults/MoTV
%dir %{_datadir}/X11/de_DE.UTF-8
%dir %{_datadir}/X11/fr_FR.UTF-8
%dir %{_datadir}/X11/it_IT.UTF-8
%lang(de) %{_datadir}/X11/de_DE.UTF-8/app-defaults
%lang(fr) %{_datadir}/X11/fr_FR.UTF-8/app-defaults
%lang(it) %{_datadir}/X11/it_IT.UTF-8/app-defaults
%{_bindir}/mtt
%{_mandir}/man1/mtt.1%{?ext_man}
%{_datadir}/X11/app-defaults/mtt
%{_datadir}/applications/motv.desktop
%{_datadir}/pixmaps/motv.xpm

%files -n tv-common
%license COPYING
%{_bindir}/subtitles
%{_mandir}/man1/subtitles.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/subtitles.1%{ext_man}
%{_bindir}/xawtv-remote
%{_mandir}/man1/xawtv-remote.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/xawtv-remote.1%{ext_man}
%{_bindir}/propwatch
%{_mandir}/man1/propwatch.1%{?ext_man}
%{_mandir}/man5/xawtvrc.5%{?ext_man}
%doc %lang(es) %{_mandir}/es/man5/xawtvrc.5.gz
%{_libdir}/xawtv
%{_datadir}/xawtv

%files -n v4l-conf
%license COPYING
%verify(not mode group) %attr(4750,root,video) %{_bindir}/v4l-conf
%{_mandir}/man8/v4l-conf.8%{?ext_man}
%doc %lang(es) %{_mandir}/es/man8/v4l-conf.8.gz

%files -n v4l-tools
%license COPYING
%{_bindir}/radio
%{_mandir}/man1/radio.1%{?ext_man}
%{_bindir}/fbtv
%{_mandir}/man1/fbtv.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/fbtv.1%{ext_man}
%{_bindir}/ttv
%{_mandir}/man1/ttv.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/ttv.1%{ext_man}
%{_bindir}/streamer
%{_mandir}/man1/streamer.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/streamer.1%{ext_man}
%{_bindir}/v4lctl
%{_mandir}/man1/v4lctl.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/v4lctl.1%{ext_man}
%{_bindir}/record
%{_mandir}/man1/record.1%{?ext_man}
%{_bindir}/dump-mixers
%{_mandir}/man1/dump-mixers.1%{?ext_man}
%{_bindir}/showriff
%{_mandir}/man1/showriff.1%{?ext_man}
%{_bindir}/showqt
%{_bindir}/scantv
%{_mandir}/man1/scantv.1%{?ext_man}
%doc %lang(es) %{_mandir}/es/man1/scantv.1%{ext_man}
%{_bindir}/ntsc-cc
%{_mandir}/man1/ntsc-cc.1%{?ext_man}
%{_bindir}/webcam
%{_mandir}/man1/webcam.1%{?ext_man}
%{_bindir}/v4l-info
%{_mandir}/man1/v4l-info.1%{?ext_man}

%files -n alevtd
%license COPYING
%{_bindir}/alevtd
%{_mandir}/man1/alevtd.1%{?ext_man}

%files -n pia
%license COPYING
%doc Changes README
%{_bindir}/pia
%{_mandir}/man1/pia.1%{?ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with glibc >= 2.32:
  * 0001-Replace-sys_siglist-with-strsignal.patch
- Drop obsolete conditions
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- skip group verify on v4l-conf
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.107:
  * Solve build issues with gcc 10.1
  * Check if file exists before opening it
  * Use standard c99 designated initializers
  * Show if lirc is enabled or not when configuring it
  * Don't need need to call abs() for rdrift and vdrift
  * Get rid of an unused function at flt-smooth
  * Use hexa for non-printable codes at ntsc-cc code
  * Move -Llibng to LD_FLAGS at makefile
  * Add xawtv3 to Tavis CI build integration
  * Get rid of VIDIOC_G_PARM ioctl
  * Remove an unused file from git and ignore auto-generated files
  * Get rid of V4L1 support, as V4L1 API got removed from Kernel in 2010.
  * Update videodev2.h file to a later version
  * Update the error code at vbi-gui to reflect the name of the V4L2 ioctl
  * Fix fbtv application for it to properly handle camera bytesperpage
    aligments and to properly display texts over over the camera
    streaming screen
  * add fbtv support for modern console fonts
  * fix fbtv output when byterperline is greater than the number of
    filled bytes
  * add help for fbtv and improve its man page
  * allow using just the font name on fbtv
  * Cleanup most warnings when building it, fixing some potential bugs
  * Add support for AC_HEADER_MAJOR, in order to support upcoming
    glibc versions
  * Allow ./configure --disable-alsa to compile when alsa is available
  * x11: get rid of deprecated XKeycodeToKeysym function
  * get rid of unused libXp at Makefile
  * disable DGA if client is not local, fixing usage over ssh
  * Drop supplementary group IDs when dropping privileges
  * Add desktop and appdata files for xawtv, motv and mtt
  * Fix mtt not being able to tune tv channels
  * Remove superfluous ; add end of functions
  * Add a workaround for bttv kernel driver planar fmt width bug
  * Allow setting alsa_latency from ~/.xawtv
  * Fix not being able to get a larger latency on capture devices with small
    max period sizes
  * prefer CAP_STREAMING over CAP_READWRITE
  * Fix segfault under certain conditions
- remove xawtv-fixblitframesegfault.patch, fix-build-with-recent-glibc.patch,
  v4l-conf-fix-CVE-2020-13696.patch, gcc-10.patch (all upstream)
* Wed Jun  3 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- add gcc-10.patch: fixes multiple definitions of global variables across the
  code. These cause errors with new major gcc 10 version.
* Fri May 29 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- v4l-conf: add v4l-conf-fix-CVE-2020-13696.patch: fix security issue in
  setuid-root program that allows for arbitrary file existence tests and
  open() with O_RDWR (bsc#1171655, CVE-2020-13696)
* Thu Apr 30 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO on %%arm and aarch64 to fix build
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build-with-recent-glibc.patch
- Run spec-cleaner
* Fri Dec 26 2014 bwiedemann@suse.com
- fix Segfault at start + add xawtv-fixblitframesegfault.patch
* Thu Jul 25 2013 tchvatal@suse.com
- Add missing dependencies so the package build on factory.
* Sun Jun  2 2013 asterios.dramis@gmail.com
- Update to version 3.103:
  * Improve alsa stream handling
  * Add support for alsa audio loopback to the radio app
  * Add support for multiple-band (AM+FM) tuners to radio app
  * Tons of other bugfixes + improvements for the radio app
  * Fix xawtv window flashing to black when changing channel or taking a
    snapshot
  * Fix crackle crackle sound on mp34xx cards when changing channel
  * Various other bugfixes
- Removed xawtv-3.95.patch, no-copy-dt-needed-entries.patch and
  xawtv-read-config.patch (not needed/fixed upstream).
- Replaced Mesa-devel and xorg-x11-devel build requirements with the needed
  pkgconfig(...) ones.
- Removed automake (autoreconf -fi is not needed) and openmotif (not needed)
  build requirements.
- Use desktop-file-utils instead of update-desktop-files for openSUSE > 12.1.
* Sat Jun 16 2012 bwiedemann@suse.com
- patch to read config as it can contain keyboard events for vdr
  (fixes bnc#735032)
* Fri Feb 24 2012 coolo@suse.com
- buildrequire xorg-x11 for configure to find appdefaults location correctly
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 10 2011 asterios.dramis@gmail.com
- Update to version 3.102:
  * Improve alsa latency handler and document the -alsa-latency parameter
  * Improve alsa handling, fixing a cut and past error that causes
    breakages with some cards
  * Improve audio parameters detection
  * fix build with ld --as-needed --no-copy-dt-needed
- Spec file updates:
  * Changed License: to GPL-2.0+.
  * Recommend instead of Require "pia" for xawtv and motv.
  * Removed "export SUSE_ASNEEDED=0" (not needed anymore).
  * Minor other updates.
- Added a patch "v4l-conf_non-position-independent-executable_fix.patch" to fix
  the non-position-independent-executable rpmlint warning for v4l-conf.
- Added a patch "no-copy-dt-needed-entries.patch" to fix linking with
  - -no-copy-dt-needed-entries.
* Sun Jul  3 2011 asterios.dramis@gmail.com
- Update to version 3.101:
  * Man fix to remove mention of v4l1, and describe libv4l instead
  * Fixes at fr/es manuals
  * Warning fixes
  * Addition of alsa streaming at xawtv: now, for devices with video
    associated with audio inputs.
  * Use X11 editres, instead of its on version, based on a port from
    a motif library released under a licence that is not GPL compatible
  * Add auto-detection logic for xawtv: by default, it will now seek for
    the first TV device. If not available, fall back to the first grabber
    device.
  * Add auto-detection logic for scanv: by default, it will now seek for
    the first TV device. If not afailable, fails.
  * Add optional support for libexplain at the v4l2/libv4l driver.
    Libexplain provides a  more complete explanation for the error codes,
    helping developers to better track what's happened.
  * Don't expose tuner commands, on devices that are grabber or  webcams
    at xawtv.
- Removed the patch for the GPL incompatible OpenGroup license files issue
  bnc#696259 (fixed upstream).
* Sat May 28 2011 asterios.dramis@gmail.com
- Added a patch (based on upstream) to fix the issue with GPL incompatible
  OpenGroup license files (bnc#696259).
* Sat May  7 2011 asterios.dramis@gmail.com
- Update to version 3.100:
  * Incorporation of patches from various distributions.
  * Porting to V4L2 API.
  * Lots of other changes (see Changes file).
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Removed libdrm-devel, recode and slang-devel from Buildrequires:
    (not needed).
  * Replaced freeglut-devel with Mesa-devel and added libdv-devel and
    libquicktime-devel in Buildrequires:.
  * Moved permissions package requirement in v4l-conf.
  * Suggest lirc for xawtv and motv.
  * Updates in Summaries and descriptions.
  * Install an icon also for motv.
  * Updates in v4l-conf post scripts.
  * Minor other updates.
- Fixed some rpmlint warnings.
- Updated motv.desktop and xawtv.desktop to be XDG compatible.
- Removed all previous openSUSE and Fedora patches (except xawtv-3.95.patch)
  since they are merged upstream, either complete or with some changes.
- Rebased xawtv-3.95.patch to aplly cleanly.
* Mon Sep  7 2009 mmarek@suse.cz
- xawtv-3.95-missing-fclose.patch: fix for bnc#532258.
* Sat Sep  5 2009 mmarek@suse.cz
- added patches from Fedora (bnc#464294).
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Mon May 25 2009 lnussel@suse.de
- lirc -> lirc-devel in BuildRequires
* Fri Apr 24 2009 crrodriguez@suse.de
- fix build, add ncurses-devel to BuildRequires
* Tue Jul 29 2008 mmarek@suse.cz
- don't print spurious error messages in xioctl() (bnc#404034)
* Mon Aug  6 2007 olh@suse.de
- remove PAGE_SIZE useage and inclusion of asm/page.h
* Sat May 19 2007 coolo@suse.de
- remove translations from desktop files
* Wed Apr 18 2007 ro@suse.de
- added %%{_mandir}/fr directory to filelist
* Fri Mar 30 2007 rguenther@suse.de
- add %%{_mandir}/fr/man1 directory.
* Mon Oct 16 2006 kraxel@suse.de
- fix build failure.
* Thu Aug 17 2006 cthiel@suse.de
- update to version 3.95
  * misc minor fixes collected over time.
  * make it build with gcc4.
- drop xawtv-gcc4.patch
- fix build with X.Org 7.1
* Fri May 19 2006 ro@suse.de
- fix build on ppc64
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Wed Oct 12 2005 sbrabec@suse.cz
- Force glib2 using gtk1-compat-devel.
- Enabled DV support.
* Fri Apr 22 2005 ro@suse.de
- hack to build with gcc4
* Fri Nov 19 2004 ro@suse.de
- include icon in file list
* Wed Nov 10 2004 ro@suse.de
- fixed permissions handling for v4l-conf
* Wed Aug 18 2004 kraxel@suse.de
- update to version 3.94.
* Thu Apr 22 2004 kraxel@suse.de
- update to version 3.92.
* Thu Jan 29 2004 kraxel@suse.de
- update to version 3.91.
* Tue Oct 28 2003 kraxel@suse.de
- %%run_permission fixes.
* Mon Oct 27 2003 kraxel@suse.de
- some spec file tweaks to make the package also build on
  older distributions.
* Fri Oct 17 2003 kraxel@suse.de
- updated to version 3.90
* Fri Sep 12 2003 kraxel@suse.de
- added bugfix for a segfault.
- added conflicts: xaw3dd to xawtv (#12466).
* Fri Aug 29 2003 kukuk@suse.de
- Change group to video for v4l-conf (like /etc/permissions has)
* Thu Aug 21 2003 kraxel@suse.de
- more file list fixes.
* Sat Aug 16 2003 adrian@suse.de
- add desktop files from kappfinder
* Thu Aug 14 2003 kraxel@suse.de
- fixup file lists (#28805).
* Wed Jun 18 2003 kraxel@suse.de
- fixup file lists.
* Mon May 26 2003 kraxel@suse.de
- fixup file lists.
* Wed Apr 16 2003 kraxel@suse.de
- updated to version 3.88
* Tue Apr 15 2003 kraxel@suse.de
- updated to version 3.87
* Mon Mar 31 2003 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Tue Mar 25 2003 kraxel@suse.de
- updates to version 3.86
* Thu Feb 20 2003 kraxel@suse.de
- fix two segfaults in motv (one of them being bug #23958).
* Mon Feb 10 2003 kraxel@suse.de
- updated to version 3.85
* Fri Feb  7 2003 kraxel@suse.de
- updated to version 3.84
* Fri Jan 17 2003 kraxel@suse.de
- updated to version 3.83
* Tue Dec 10 2002 kraxel@suse.de
- updated to version 3.81
* Fri Nov 15 2002 kraxel@suse.de
- updated to version 3.79
* Fri Aug 16 2002 kraxel@suse.de
- added alevtd bugfix.
* Wed Jul 24 2002 kraxel@suse.de
- updated to version 3.76
- more neededforbuild fixes (alsa, mesa, lirc).
* Fri Jun 21 2002 ro@suse.de
- added xf86 and libjpeg to neededforbuild
- added glib,glib-devel to neededforbuild (for libquicktime)
- added openmotif,openmotif-devel (for motv)
- added aalib,aalib-devel,slang,slang-devel (for ttv)
* Thu Jun 20 2002 kraxel@suse.de
- updated to version 3.75
* Mon Mar 18 2002 kraxel@suse.de
- one-liner Fix for ppm snapshots.
* Fri Feb 22 2002 kraxel@suse.de
- updated to version 3.72
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 kraxel@suse.de
- updated to version 3.68
* Tue Sep 11 2001 kraxel@suse.de
- fixed bugzilla #10420
- merged another one-liner fix for a segfault from current
  xawtv tree.
* Mon Sep  3 2001 kraxel@suse.de
- updated to version 3.61
* Thu Aug 30 2001 ro@suse.de
- added slang to neededforbuild (for aalib)
* Wed Aug 15 2001 kraxel@suse.de
- updated to version 3.60
* Mon Jul 30 2001 kraxel@suse.de
- updated to version 3.57
* Fri Jul 20 2001 kraxel@suse.de
- splitted into multiple, smaller packages.
* Tue Jul 17 2001 kraxel@suse.de
- updated to version 3.56
* Wed Jul 11 2001 kraxel@suse.de
- updated to version 3.55
* Mon Jun 25 2001 kraxel@suse.de
- updated to version 3.53
* Mon Apr 30 2001 kraxel@suse.de
- Deleted the %%post script with mkfontdir.  It's not required as
  /sbin/conf.d/SuSEconfig.fonts does that and causes problems
  at install time [bug #7425]
* Mon Apr  9 2001 kraxel@suse.de
- updated to version 3.43
- fixed %%post script
* Fri Apr  6 2001 kraxel@suse.de
- updated to version 3.42
- build with quicktime4linux lib and xfree4
- created new subpackage for alevtd
* Thu Apr  5 2001 uli@suse.de
- removed lx_suse from neededforbuild
* Wed Jan 10 2001 ro@suse.de
- fixed doc list
* Mon Jan  8 2001 mt@suse.de
- renamed consolefont lat1-16.psf* to lat1-16.psfu* in fbtools.c
* Sun Aug 27 2000 mt@suse.de
- added xf86_3x and xdevel3 to #needforbuild
* Tue Jul  4 2000 mt@suse.de
- update to 3.17 (works really fine with lx_suse >= 2.2.16-7)
- kradio is not a part of the xawtv source any more
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 bs@suse.de
- fixed call of Check at the end of %%install section
* Sat Jul 17 1999 mt@suse.de
- updated to 2.46 (bug fixes version)
- added some security patches
* Wed Jun  2 1999 mt@suse.de
- fixed ChannelEditor PopDown-Action (Close Button)
* Wed Jun  2 1999 mt@suse.de
- updated to 2.45
- adapted security fixes/checks by marc from previous releases
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Thu Mar 25 1999 mt@suse.de
- security fixes/checks by marc
* Fri Mar 19 1999 mt@suse.de
- fixed filelist in spec
* Fri Mar 19 1999 mt@suse.de
- new version 2.38
* Mon Nov 16 1998 mt@suse.de
- new version 2.29
* Wed Oct  7 1998 ro@suse.de
- detect which directory contains QT
* Mon Jul 13 1998 mt@suse.de
- added /usr/bin/radio, changed /dev/radio to /dev/bttv-fm (c,81,64)
* Sat Jul 11 1998 bs@suse.de
- fixed neededforbuild
* Fri Jul 10 1998 mt@suse.de
- new version 2.14 with v4l interface
